==> file_storage_handler_abm-7.0.63507a0.tar.gz: file_storage_handler_abm-7.0.63507a0/file_storage_handler/file_downloader.py <==
#  Copyright (C) 2024
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Vasya Svintsov <v.svintsov@techokert.ru>
from dataclasses import dataclass

import aiohttp.hdrs
from aiohttp import ClientSession, ClientTimeout

from .tools.extension_to_mime_type import mime_type_to_extension
from .tools.get_filename_from_headers import get_filename_from_headers


@dataclass
class FileMetadata:
    filename: str | None
    extension: str | None
    size: int | None
    etag: str | None

    @property
    def clear_etag(self) -> str | None:
        if self.etag:
            return self.etag.replace('"', '')


class FileDownloader:
    @dataclass
    class Config:
        timeout_sec: float = 100

    @dataclass
    class Context:
        session: ClientSession

    def __init__(self, config: Config, context: Context) -> None:
        self.context = context
        self.config = config

    async def head(self, file_url: str) -> FileMetadata:
        async with self.context.session.head(file_url, timeout=ClientTimeout(self.config.timeout_sec)) as answer:
            answer.raise_for_status()
            return FileMetadata(get_filename_from_headers(answer.headers),
                                mime_type_to_extension.get(answer.headers.get(aiohttp.hdrs.CONTENT_TYPE)),
                                answer.content_length,
                                answer.headers.get(aiohttp.hdrs.ETAG),
                                )

    async def get(self, file_url: str) -> tuple[str | None, bytes]:
        async with self.context.session.get(file_url, timeout=ClientTimeout(self.config.timeout_sec)) as answer:
            answer.raise_for_status()
            return get_filename_from_headers(answer.headers), await answer.read()

==> file_storage_handler_abm-7.0.63544.tar.gz: file_storage_handler_abm-7.0.63544/file_storage_handler/file_downloader.py <==
#  Copyright (C) 2024
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Vasya Svintsov <v.svintsov@techokert.ru>
from dataclasses import dataclass
from typing import Mapping

import aiohttp.hdrs
from aiohttp import ClientSession, ClientTimeout

from .extra import assert_raise
from .tools.extension_to_mime_type import mime_type_to_extension
from .tools.get_filename_from_headers import get_filename_from_headers


@dataclass
class FileMetadata:
    filename: str
    extension: str | None
    size: int | None
    etag: str | None

    @property
    def clear_etag(self) -> str | None:
        if self.etag:
            return self.etag.replace('"', '')


def _get_filename_from_headers(headers: Mapping[str, str]) -> str:
    filename = get_filename_from_headers(headers)
    assert_raise(filename, ValueError, 'filename is missing in headers')
    return filename


class FileDownloader:
    @dataclass
    class Config:
        timeout_sec: float = 100

    @dataclass
    class Context:
        session: ClientSession

    def __init__(self, config: Config, context: Context) -> None:
        self.context = context
        self.config = config

    async def head(self, file_url: str) -> FileMetadata:
        async with self.context.session.head(file_url, timeout=ClientTimeout(self.config.timeout_sec)) as answer:
            answer.raise_for_status()
            return FileMetadata(_get_filename_from_headers(answer.headers),
                                mime_type_to_extension.get(answer.headers.get(aiohttp.hdrs.CONTENT_TYPE)),
                                answer.content_length,
                                answer.headers.get(aiohttp.hdrs.ETAG),
                                )

    async def get(self, file_url: str) -> tuple[str, bytes]:
        async with self.context.session.get(file_url, timeout=ClientTimeout(self.config.timeout_sec)) as answer:
            answer.raise_for_status()
            return _get_filename_from_headers(answer.headers), await answer.read()
